@@ -1,7 +1,10 @@
+from __future__ import (absolute_import, division, print_function)
+
 import os
 import sys
-import yaml
+
 import netCDF4
+import ruamel.yaml as yaml
 
 from docopt import docopt
 
@@ -65,8 +68,7 @@ def add_global_atts(text, a):
                 text += str_att('_'.join([key, 'name']), name)
         elif key in ['contributor']:
             role = value.get("role", None)
-            if email:
-                text += str_att('_'.join([key, 'role']), role)
+            text += str_att('_'.join([key, 'role']), role)
             email = value.get("email", None)
             if email:
                 text += str_att('_'.join([key, 'email']), email)
@@ -79,6 +81,22 @@ def add_global_atts(text, a):
     return text
 
 
+def add_bed_coord(text, a):
+    ncfile = os.path.join(a['aggregation']['dir'],
+                          a['aggregation']['sample_file'])
+    nc = netCDF4.Dataset(ncfile)
+    bed_coord_var = """<variable name="Nbed" shape="Nbed" type="double">
+      <attribute name="long_name" value="pseudo coordinate at seabed points"/>
+      <attribute name="standard_name" value="ocean_sigma_coordinate"/>
+      <attribute name="positive" value="up"/>
+      <attribute name="formula_terms" value="sigma: Nbed eta: zeta depth: h"/>
+      <values start="-1.0" increment="-0.01"/>
+    </variable>\n """
+    if 'Nbed' in nc.dimensions.keys():
+        text += bed_coord_var
+    return text
+
+
 def add_var_atts(text, a):
     ncfile = os.path.join(a['aggregation']['dir'],
                           a['aggregation']['sample_file'])
@@ -135,6 +153,9 @@ def add_var_atts(text, a):
             pass
         text += str_att('grid', 'grid')
 
+        if 'Nbed' in ncv[var].dimensions:
+            text += str_att('coordinates', ncv[var].coordinates+' Nbed')
+
         if var in vars_display:
             text += str_att('display', 'True')
         else:
@@ -159,6 +180,7 @@ def add_var_atts(text, a):
         except:
             pass
 
+    nc.close()
     return text
 
 
@@ -176,7 +198,7 @@ def write_grid_var(text):
         <attribute name="edge1_coordinates" value="lon_u lat_u"/>
         <attribute name="edge2_coordinates" value="lon_v lat_v"/>
         <attribute name="vertical_dimensions" value="s_rho: s_w (padding: none)"/>
-    </variable>\n """
+    </variable>\n"""  # noqa
     text += grid_var
     return text
 
@@ -185,10 +207,10 @@ def add_aggregation_scan(text, a):
     agg = a['aggregation']
     text += '<aggregation dimName="{:s}" type="joinExisting">\n'.format(
         agg['time_var'])
-    text += '<scan location="{:s}" regExp="{:s}" subdirs="false"/>\n</aggregation>\n'.format(
-        agg['dir'], agg['pattern'])
+    text += '<scan location="{:s}" regExp="{:s}" subdirs="false"/>\n</aggregation>\n'.format(agg['dir'], agg['pattern'])  # noqa
     return text
 
+
 # Map ROMS variables to CF standard_names.
 cf = dict(ocean_time='time',
           zeta='sea_surface_height_above_datum',
@@ -198,7 +220,8 @@ cf = dict(ocean_time='time',
           v='y_sea_water_velocity',
           ubar='barotropic_x_sea_water_velocity',
           vbar='barotropic_y_sea_water_velocity',
-          Hwave='sea_surface_wave_significant_height')
+          Hwave='sea_surface_wave_significant_height',
+          bed_thickness='sediment_bed_thickness')
 
 
 def build(yml):
@@ -206,18 +229,19 @@ def build(yml):
     text = add_global_atts(text, yml)
     text = add_var_atts(text, yml)
     text = write_grid_var(text)
+    text = add_bed_coord(text, yml)
     text = add_aggregation_scan(text, yml)
     text = footer(text)
     return text
 
 
 def main():
-    args = docopt(__doc__, version='0.1.0')
+    args = docopt(__doc__, version='0.6.0')
     fname = args.get('INFILE')
     fout = args.get('--output', None)
 
     with open(fname, 'r') as stream:
-        yml = yaml.safe_load(stream)
+        yml = yaml.load(stream, Loader=yaml.RoundTripLoader)
 
     text = build(yml)
 
